@@ -1,18 +1,19 @@
 use std::time::{Duration, Instant, SystemTime, UNIX_EPOCH};
 
+use anyhow::Result as AnyResult;
 use rand::prelude::*;
 use serde_json::{json, Value};
 use tracing::{
     span::{Attributes, Record},
     Event, Id, Level, Subscriber,
 };
-use tracing_subscriber::{layer::Context, registry::LookupSpan, Layer};
+use tracing_subscriber::{Layer, layer::Context, registry::LookupSpan};
 
 use crate::{
     apm_client::{ApmClient, Batch},
     config::Config,
     model::{Agent, Error, Log, Metadata, Service, Span, Transaction},
-    visitor::ApmVisitor,
+    visitor::{ApmVisitor, TraceIdVisitor},
 };
 
 #[derive(Copy, Clone)]
@@ -56,8 +57,8 @@ where
 
         let name = span.name().to_string();
 
-        if let Some(parent_id) = span.parent_id() {
-            let parent_span = ctx.span(parent_id).expect("Span parent not found!");
+        if let Some(parent_id) = span.parent().map(|span_ref| span_ref.id()) {
+            let parent_span = ctx.span(&parent_id).expect("Span parent not found!");
             let parent_extensions = parent_span.extensions();
             let trace_ctx = parent_extensions
                 .get::<TraceContext>()
@@ -76,8 +77,11 @@ where
             extensions.insert(new_span);
             extensions.insert(*trace_ctx);
         } else {
+            let mut visitor = TraceIdVisitor::default();
+            attrs.record(&mut visitor);
+
             let trace_ctx = TraceContext {
-                trace_id: thread_rng().gen(),
+                trace_id: visitor.0.unwrap_or_else(|| thread_rng().gen()),
             };
 
             let new_transaction = Transaction {
@@ -208,7 +212,7 @@ where
 }
 
 impl ApmLayer {
-    pub(crate) fn new(mut config: Config, service_name: String) -> Self {
+    pub(crate) fn new(mut config: Config, service_name: String) -> AnyResult<Self> {
         let metadata = Metadata {
             service: Service {
                 name: service_name,
@@ -249,14 +253,15 @@ impl ApmLayer {
             labels: None,
         };
 
-        ApmLayer {
+        Ok(ApmLayer {
             client: ApmClient::new(
                 config.apm_address,
                 config.authorization,
                 config.allow_invalid_certs,
-            ),
+                config.root_cert_path,
+            )?,
             metadata: json!(metadata),
-        }
+        })
     }
 
     fn create_metadata(
